summaryrefslogtreecommitdiff
path: root/sql/sp_head.h
diff options
context:
space:
mode:
authorunknown <pem@mysql.com>2002-12-19 18:43:25 +0100
committerunknown <pem@mysql.com>2002-12-19 18:43:25 +0100
commita3fe4223e89ea4e5857005181367faccf2c7bed6 (patch)
tree27fe9e31d72478159f921eacfcedf4bea1d40ea6 /sql/sp_head.h
parentb12330b3d9597b6da2ee8ef51765093e9de38e42 (diff)
downloadmariadb-git-a3fe4223e89ea4e5857005181367faccf2c7bed6.tar.gz
Fixed some of the data collection during parsing.
sql/sp_head.cc: Renamed m_mylex into m_call_lex. Fixed some data collection. sql/sp_head.h: Renamed m_mylex into m_call_lex. Put called procedures and used tables in class member vars (for now at least).
Diffstat (limited to 'sql/sp_head.h')
-rw-r--r--sql/sp_head.h4
1 files changed, 3 insertions, 1 deletions
diff --git a/sql/sp_head.h b/sql/sp_head.h
index f6d06b61f43..820193e8184 100644
--- a/sql/sp_head.h
+++ b/sql/sp_head.h
@@ -36,6 +36,8 @@ class sp_head : public Sql_alloc
public:
my_bool m_simple_case; // TRUE if parsing simple case, FALSE otherwise
+ List<Item_string> m_calls; // Called procedures.
+ List<char *> m_tables; // Used tables.
static void *operator new(size_t size)
{
@@ -89,7 +91,7 @@ private:
Item_string *m_name;
Item_string *m_defstr;
- LEX *m_mylex; // My own lex
+ LEX *m_call_lex; // The CALL's own lex
LEX m_lex; // Temp. store for the other lex
DYNAMIC_ARRAY m_instr; // The "instructions"
typedef struct